aboutsummaryrefslogtreecommitdiffhomepage
diff options
context:
space:
mode:
authorGravatar ncteisen <ncteisen@gmail.com>2017-06-11 22:44:00 -0700
committerGravatar ncteisen <ncteisen@gmail.com>2017-06-14 11:05:54 -0700
commit12da4ccb525498d7bffb66bc0c2b43263c1e9e9f (patch)
tree6103bf68ae0fe0fec429e5af059e7fe5518471d1
parent351506688d0afaa3d03764b6d2445c33eb1592a4 (diff)
Add trickle diff jenkins job
-rwxr-xr-xtools/jenkins/run_performance.sh7
-rwxr-xr-xtools/jenkins/run_performance_old.sh26
-rw-r--r--tools/profiling/microbenchmarks/bm_diff/bm_constants.py3
3 files changed, 30 insertions, 6 deletions
diff --git a/tools/jenkins/run_performance_old.sh b/tools/jenkins/run_performance_old.sh
new file mode 100755
index 0000000000..3ce05cc7f1
--- /dev/null
+++ b/tools/jenkins/run_performance_old.sh
@@ -0,0 +1,26 @@
+#!/usr/bin/env bash
+# Copyright 2015 gRPC authors.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
+# This script is invoked by Jenkins and runs a diff on the microbenchmarks
+set -ex
+
+# List of benchmarks that provide good signal for analyzing performance changes in pull requests
+BENCHMARKS_TO_RUN="bm_fullstack_unary_ping_pong bm_fullstack_streaming_ping_pong bm_fullstack_streaming_pump bm_closure bm_cq bm_call_create bm_error bm_chttp2_hpack bm_chttp2_transport bm_pollset bm_metadata"
+
+# Enter the gRPC repo root
+cd $(dirname $0)/../..
+
+tools/run_tests/start_port_server.py
+tools/profiling/microbenchmarks/bm_diff/bm_main.py -d origin/$ghprbTargetBranch -b $BENCHMARKS_TO_RUN
diff --git a/tools/profiling/microbenchmarks/bm_diff/bm_constants.py b/tools/profiling/microbenchmarks/bm_diff/bm_constants.py
index 2bbd987b20..4cd65867c3 100644
--- a/tools/profiling/microbenchmarks/bm_diff/bm_constants.py
+++ b/tools/profiling/microbenchmarks/bm_diff/bm_constants.py
@@ -26,4 +26,5 @@ _AVAILABLE_BENCHMARK_TESTS = [
_INTERESTING = ('cpu_time', 'real_time', 'locks_per_iteration',
'allocs_per_iteration', 'writes_per_iteration',
'atm_cas_per_iteration', 'atm_add_per_iteration',
- 'nows_per_iteration',)
+ 'nows_per_iteration', 'cli_transport_stalls', 'cli_stream_stalls',
+ 'svr_transport_stalls', 'svr_stream_stalls',)
diff --git a/tools/jenkins/run_performance.sh b/tools/jenkins/run_performance.sh
index 177b076650..7b88512ee0 100755
--- a/tools/jenkins/run_performance.sh
+++ b/tools/jenkins/run_performance.sh
@@ -13,14 +13,11 @@
# See the License for the specific language governing permissions and
# limitations under the License.
#
# This script is invoked by Jenkins and runs performance smoke test.
set -ex
-# List of benchmarks that provide good signal for analyzing performance changes in pull requests
-BENCHMARKS_TO_RUN="bm_fullstack_unary_ping_pong bm_fullstack_streaming_ping_pong bm_fullstack_streaming_pump bm_closure bm_cq bm_call_create bm_error bm_chttp2_hpack bm_chttp2_transport bm_pollset bm_metadata"
-
# Enter the gRPC repo root
cd $(dirname $0)/../..
tools/run_tests/start_port_server.py
-tools/profiling/microbenchmarks/bm_diff/bm_main.py -d origin/$ghprbTargetBranch -b $BENCHMARKS_TO_RUN
+tools/profiling/microbenchmarks/bm_diff/bm_main.py -d origin/$ghprbTargetBranch -b bm_fullstack_trickle -l 4 -t cli_transport_stalls cli_stream_stalls svr_transport_stalls svr_stream_stalls
@@ -13,14 +13,11 @@
# limitations under the License.
#
-# This script is invoked by Jenkins and runs performance smoke test.
+# This script is invoked by Jenkins and runs a diff on bm_fullstack_trickle
set -ex